@@ -5,8 +5,6 @@ from ..transport import DoHomeBroadcastTransport
 from .light import DoHomeLight
 from .light import parse_response
 
-NotAllException = Exception("Not all lights responds")
-
 class DoHomeLightsBroadcast(DoHomeLight):
     """DoHome broadcast light controller class"""
     _transport: DoHomeBroadcastTransport
@@ -22,8 +20,8 @@ class DoHomeLightsBroadcast(DoHomeLight):
             request, self._timeout, len(self._sids)
         )
         responses = list(map(parse_response, response_data))
-        if len(responses) != len(self._sids):
-            raise NotAllException
+        if len(responses) < len(self._sids):
+            raise Exception(f"Not all lights responds: {len(responses)} from {len(self._sids)}")
         for response in responses:
             if response["res"] != 0:
                 raise Exception('Command error')
